@@ -1,6 +1,6 @@
 package Math::PariBuild;
 
-$VERSION = '1.000';
+$VERSION = '1.001';
 
 require Exporter;
 @ISA = 'Exporter';
@@ -611,7 +611,7 @@ EOP
   return 1;
 }
 
-=item write_paricfg()
+=item write_paricfg($formatted_version)
 
 Writes PARI configuration file F<libPARI/paricfg.h>.  Returns hash
 with options found during the scan of the header files.
@@ -619,6 +619,7 @@ with options found during the scan of the header files.
 =cut
 
 sub write_paricfg {
+  my $version = shift;
   my %opts;
   scan_headers(\%opts) or $opts{clk_tck_def} = 0;
   warn "Creating libPARI/paricfg.h...\n";
@@ -696,6 +697,16 @@ EOP
   print F <<EOP if $arch eq 'port';
 #define __HAS_NO_ASM__
 
+EOP
+
+  my @v = ($version =~ /^(\d+)(\d{3})(\d{3})$/)
+    or die "write_paricfg() needs a formatted version argument, got `$version'";
+  my $vvv = ((($v[0]) << 16) + (($v[1]) << 8) + ($v[2]));
+  print F <<EOP;   # <=2.3.0 it was used only in gp.c, which we don't compile
+#define PARI_VERSION_CODE	$vvv
+#define PARI_VERSION(a,b,c)	(((a) << 16) + ((b) << 8) + (c))
+#define PARI_VERSION_SHIFT	8
+
 EOP
 
   close F or die "close 'libPARI/paricfg.h' for write: $!";
@@ -711,8 +722,8 @@ header files.
 
 =cut
 
-sub build_paricfg {
-  my ($paridir, $do_configure) = (shift, shift);
+sub build_paricfg {	# $version as in 2003005 for 2.3.5
+  my ($paridir, $do_configure, $version) = (shift, shift, shift);
   my %opts;
   unless (find_or_Configure_paricfg($paridir, $do_configure)) {
     # Not generated by Configure
@@ -724,7 +735,7 @@ sub build_paricfg {
 EOP
     } else {
       print "...Generating libPARI/paricfg.h ...\n";
-      %opts = write_paricfg();
+      %opts = write_paricfg($version);
     }
   }
   %opts;
